package org.greenstone.gsdl3.gs3build.metadata;

import java.io.PrintWriter;

import java.util.List;
import java.util.ArrayList;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.Iterator;

/**
 *  A helpful 'superclass' of METSStructure and METSDivision which allows for some
 *  simple generalisation of the two classes.
 */

public abstract class AbstractStructure
{ Map               children;
  AbstractStructure parent;
  String            ID;     // the unique identifier for this division (unique within the
                            // document, not necessarily unique within the collection).

  public AbstractStructure(String ID)
  { this.children = new LinkedHashMap();
    this.parent   = null;
    this.ID       = ID;
  }

  public AbstractStructure getParent()
  { return this.parent;
  }

  public void setParent(AbstractStructure parent)
  { this.parent = parent;
  }

  /**
   *  Get the identifer of this structure
   *
   *  @param <code>String</code> the identifier.
   */
  public String getID()
  { return this.ID;
  }

  public abstract String getStructureType();

  /**
   *  Add a child division, or sub-division to the document.  For example,
   *  sections within a chapter.
   *
   *  @param <code>METSDivision</code> the child division.
   */
  public void addDivision(METSDivision child)
  { this.children.put(child.getLabel(), child);
    child.setParent(this);
  }

  public Iterator getChildIterator()
  { return this.children.values().iterator();
  }
    
  public int size()
  { return this.children.size();
  }
}

